@@ -16,7 +16,7 @@
 #include "umlrole.h"
 
 // kde includes
-#include <klocale.h>
+#include <KLocalizedString>
 
 namespace Uml
 {
