@@ -30,7 +30,7 @@ CodeComment::~CodeComment()
  */
 void CodeComment::saveToXMI (QDomDocument & doc, QDomElement & root)
 {
-    QDomElement blockElement = doc.createElement("codecomment");
+    QDomElement blockElement = doc.createElement(QLatin1String("codecomment"));
     setAttributesOnNode(doc, blockElement); // as we added no additional fields to this class we may
     // just use parent TextBlock method
     root.appendChild(blockElement);
