@@ -21,11 +21,16 @@
 
 // kde includes
 #include <kconfig.h>
+#if QT_VERSION < 0x050000
 #include <kstandarddirs.h>
+#endif
 
 // qt includes
 #include <QDateTime>
 #include <QRegExp>
+#if QT_VERSION >= 0x050000
+#include <QStandardPaths>
+#endif
 #include <QStringList>
 #include <QTextStream>
 
@@ -320,13 +325,8 @@ void CodeGenerationPolicy::calculateIndentation ()
         break;
     }
 
-    if (Settings::optionState().codeGenerationState.indentationAmount > 999) {  //:TODO: fix this - no initialization
-         uDebug() << "too big indentation amount = " << Settings::optionState().codeGenerationState.indentationAmount;
-    }
-    else {
-        for (int i = 0; i < Settings::optionState().codeGenerationState.indentationAmount; ++i) {
-            m_indentation += indent;
-        }
+    for (int i = 0; i < Settings::optionState().codeGenerationState.indentationAmount; ++i) {
+        m_indentation += indent;
     }
 }
 
@@ -481,8 +481,14 @@ void CodeGenerationPolicy::setDefaults(bool emitUpdateSignal)
 
     path = UmbrelloSettings::headingsDirectory();
     if (path.isEmpty()) {
+#if QT_VERSION >= 0x050000
+        path =  QStandardPaths::locateAll(QStandardPaths::GenericDataLocation,
+                                          QLatin1String("umbrello/headings"),
+                                          QStandardPaths::LocateDirectory).first();
+#else
         KStandardDirs stddirs;
         path =  stddirs.findDirs("data", QLatin1String("umbrello/headings")).first();
+#endif
     }
     setHeadingFileDir (path);
 
@@ -595,4 +601,3 @@ QString CodeGenerationPolicy::getHeadingFile(const QString& str)
     return retstr;
 }
 
-#include "codegenerationpolicy.moc"
