@@ -28,7 +28,7 @@ public:
     /**
      * Constructors.
      */
-    explicit CPPCodeComment (CodeDocument * doc, const QString & text = "");
+    explicit CPPCodeComment (CodeDocument * doc, const QString & text = QString());
 
     /**
      * Empty Destructor.
@@ -49,7 +49,7 @@ public:
      * UnFormat a long text string. Typically, this means removing
      * the indentaion (linePrefix) and/or newline chars from each line.
      */
-    virtual QString unformatText (const QString & text, const QString & indent = "");
+    virtual QString unformatText (const QString & text, const QString & indent = QString());
 
     /**
      * A special version here because we want to not only indent
