@@ -20,6 +20,7 @@
 #include "cppcodegenerationpolicy.h"
 #include "cppcodeclassfield.h"
 #include "cppcodedocumentation.h"
+#include "debug_utils.h"
 #include "umlobject.h"
 #include "umlrole.h"
 #include "uml.h"
@@ -45,8 +46,24 @@ void CPPHeaderCodeAccessorMethod::updateContent()
 {
     CodeClassField * parentField = getParentClassField();
     CPPCodeClassField * cppfield = dynamic_cast<CPPCodeClassField*>(parentField);
+
+    // Check for dynamic casting failure!
+    if (cppfield == NULL)
+    {
+        uError() << "cppfield: invalid dynamic cast";
+        return;
+    }
+
     CodeGenPolicyExt *pe = UMLApp::app()->policyExt();
     CPPCodeGenerationPolicy * policy = dynamic_cast<CPPCodeGenerationPolicy*>(pe);
+
+    // Check for dynamic casting failure!
+    if (policy == NULL)
+    {
+        uError() << "policy: invalid dynamic cast";
+        return;
+    }
+
     bool isInlineMethod = policy->getAccessorsAreInline();
     // Uml::Visibility scope = parentField->getVisibility();
     QString variableName = cppfield->getFieldName();
@@ -152,4 +169,3 @@ void CPPHeaderCodeAccessorMethod::updateMethodDeclaration()
     setOverallIndentationLevel(1);
 }
 
-#include "cppheadercodeaccessormethod.moc"
