@@ -274,17 +274,7 @@ void RubyClassifierCodeDocument::loadChildTextBlocksFromNode(QDomElement & root)
 
     if (!loadCheckForChildrenOK)
     {
-        CodeDocument * test = dynamic_cast<CodeDocument*>(this);
-        if (test)
-        {
-            uWarning()<<" loadChildBlocks : unable to initialize any child blocks in doc: "<<test->getFileName()<<" "<<this;
-        } else {
-            HierarchicalCodeBlock * hb = dynamic_cast<HierarchicalCodeBlock*>(this);
-            if (hb)
-                uWarning()<<" loadChildBlocks : unable to initialize any child blocks in Hblock: "<<hb->getTag()<<" "<<this;
-            else
-                uDebug()<<" loadChildBlocks : unable to initialize any child blocks in UNKNOWN OBJ:"<<this;
-        }
+        uWarning()<<" loadChildBlocks : unable to initialize any child blocks in doc: " << getFileName() << " " << this;
     }
 }
 
@@ -609,4 +599,3 @@ void RubyClassifierCodeDocument::updateContent()
 }
 
 
-#include "rubyclassifiercodedocument.moc"
