@@ -37,7 +37,8 @@ int CSharpImport::s_parseDepth = 0;
  * Constructor.
  */
 CSharpImport::CSharpImport(CodeImpThread* thread)
-  : NativeImportBase(QLatin1String("//"), thread)
+  : NativeImportBase(QLatin1String("//"), thread),
+    m_defaultCurrentAccess(Uml::Visibility::Public)
 {
     setMultiLineComment(QLatin1String("/*"), QLatin1String("*/"));
     initVars();
