@@ -36,8 +36,9 @@
 #include <QRegExp>
 
 CppTree2Uml::CppTree2Uml(const QString& fileName, CodeImpThread* thread)
-    : m_anon(0), m_nsCnt(0), m_clsCnt(0), m_thread(thread)
+  : m_thread(thread)
 {
+    clear();
     QDir dir(fileName);
     m_fileName = dir.canonicalPath();
 }
