@@ -24,8 +24,8 @@
 // kde includes
 #include <kcombobox.h>
 #include <klineedit.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <KLocalizedString>
+#include <KMessageBox>
 #include <ktextedit.h>
 
 // qt includes
@@ -93,7 +93,9 @@ void AssociationGeneralPage::constructWidget()
 
     m_pAssocNameLE = new KLineEdit(m_pAssociationWidget->name());
     m_pAssocNameComB = new KComboBox(true, nameAndTypeGB);
+#if QT_VERSION < 0x050000
     m_pAssocNameComB->setCompletionMode(KGlobalSettings::CompletionPopup);
+#endif
     m_pAssocNameComB->setDuplicatesEnabled(false);  // only allow one of each type in box
 
     QWidget *nameInputWidget = m_pAssocNameLE;
@@ -175,7 +177,9 @@ void AssociationGeneralPage::constructWidget()
     m_pTypeCB->setCompletedItems(m_AssocTypeStrings);
 
     m_pTypeCB->setDuplicatesEnabled(false); // only allow one of each type in box
+#if QT_VERSION < 0x050000
     m_pTypeCB->setCompletionMode(KGlobalSettings::CompletionPopup);
+#endif
     m_pNameAndTypeLayout->addWidget(m_pTypeCB, 1, 1);
 
     // document
@@ -228,4 +232,3 @@ void AssociationGeneralPage::apply()
     }
 }
 
-#include "associationgeneralpage.moc"
