@@ -26,8 +26,8 @@
 #include <klineedit.h>
 #include <kcombobox.h>
 #include <kcompletion.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <KLocalizedString>
+#include <KMessageBox>
 
 // qt includes
 #include <QApplication>
@@ -104,7 +104,9 @@ void UMLEntityAttributeDialog::setupDialog()
     valuesLayout->addWidget(m_pAttributesL, 7, 0);
 
     m_pAttributesCB = new KComboBox(true, m_pValuesGB);
+#if QT_VERSION < 0x050000
     m_pAttributesCB->setCompletionMode(KGlobalSettings::CompletionPopup);
+#endif
     valuesLayout->addWidget(m_pAttributesCB, 7, 1);
     m_pTypeL->setBuddy(m_pAttributesCB);
 
@@ -150,7 +152,9 @@ void UMLEntityAttributeDialog::setupDialog()
     }
 
     m_pTypeCB->setDuplicatesEnabled(false); // only allow one of each type in box
+#if QT_VERSION < 0x050000
     m_pTypeCB->setCompletionMode(KGlobalSettings::CompletionPopup);
+#endif
     insertTypesSorted(m_pEntityAttribute->getTypeName());
 
     m_pNameLE->setFocus();
@@ -292,4 +296,3 @@ void UMLEntityAttributeDialog::slotAutoIncrementStateChanged(bool checked)
 
 }
 
-#include "umlentityattributedialog.moc"
