@@ -11,7 +11,7 @@
 #ifndef UMLTEMPLATEDIALOG_H
 #define UMLTEMPLATEDIALOG_H
 
-#include <kdialog.h>
+#include "singlepagedialogbase.h"
 
 class DocumentationWidget;
 class KComboBox;
@@ -19,6 +19,7 @@ class KLineEdit;
 class QGroupBox;
 class QLabel;
 class UMLTemplate;
+class UMLStereotypeWidget;
 
 /**
  * A dialog to edit the properties of a class template (paramaterised class)
@@ -26,7 +27,7 @@ class UMLTemplate;
  * @author Jonathan Riddell
  * Bugs and comments to umbrello-devel@kde.org or http://bugs.kde.org
  */
-class UMLTemplateDialog : public KDialog
+class UMLTemplateDialog : public SinglePageDialogBase
 {
     Q_OBJECT
 public:
@@ -37,7 +38,7 @@ protected:
 
     void setupDialog();
 
-    bool apply();
+    virtual bool apply();
 
     /**
      *   The Attribute to represent
@@ -46,17 +47,12 @@ protected:
 
     // GUI Widgets
     QGroupBox *m_pValuesGB;
-    QLabel *m_pTypeL, *m_pNameL, *m_pStereoTypeL;
+    QLabel *m_pTypeL, *m_pNameL;
     KComboBox *m_pTypeCB;
-    KLineEdit *m_pNameLE, *m_pStereoTypeLE;
+    KLineEdit *m_pNameLE;
+    UMLStereotypeWidget *m_stereotypeWidget;
     DocumentationWidget *m_docWidget;
 
-public slots:
-
-    void slotApply();
-
-    void slotOk();
-
 protected:
 
     void insertTypesSorted(const QString& type = QString());
