@@ -23,12 +23,16 @@
 #include "umlwidgetstylepage.h"
 
 // kde includes
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kfontdialog.h>
-#include <kvbox.h>
+#if QT_VERSION < 0x050000
+#include <kfontchooser.h>
+#endif
+#include <KLocalizedString>
+#include <KMessageBox>
 
 // qt includes
+#if QT_VERSION >= 0x050000
+#include <QFontDialog>
+#endif
 #include <QFrame>
 #include <QHBoxLayout>
 
@@ -41,7 +45,6 @@ UMLViewDialog::UMLViewDialog(QWidget * pParent, UMLScene * pScene)
 {
     setCaption(i18n("Properties"));
     m_pScene = pScene;
-    m_options = m_pScene->optionState();
     setupPages();
     connect(this, SIGNAL(okClicked()), this, SLOT(slotOk()));
     connect(this, SIGNAL(applyClicked()), this, SLOT(slotApply()));
@@ -107,12 +110,7 @@ void UMLViewDialog::setupDisplayPage()
         return;
     }
 
-    if (m_pScene->type() != Uml::DiagramType::Class) {
-        m_pOptionsPage = new ClassOptionsPage(0, m_pScene);
-    }
-    else {
-        m_pOptionsPage = new ClassOptionsPage(0, &m_options);
-    }
+    m_pOptionsPage = new ClassOptionsPage(0, m_pScene);
     m_pageDisplayItem = createPage(i18nc("classes display options page", "Display"), i18n("Classes Display Options"),
                                    Icon_Utils::it_Properties_Display, m_pOptionsPage);
 }
@@ -132,8 +130,14 @@ void UMLViewDialog::setupStylePage()
  */
 void UMLViewDialog::setupFontPage()
 {
+#if QT_VERSION >= 0x050000
+    m_pChooser = new QFontDialog();
+    m_pChooser->setCurrentFont(m_pScene->optionState().uiState.font);
+    m_pChooser->setOption(QFontDialog::NoButtons);
+#else
     m_pChooser = new KFontChooser(0, KFontChooser::NoDisplayFlags, QStringList(), 0);
     m_pChooser->setFont(m_pScene->optionState().uiState.font);
+#endif
     m_pageFontItem = createPage(i18n("Font"), i18n("Font Settings"),
                                 Icon_Utils::it_Properties_Font, m_pChooser);
 }
@@ -158,24 +162,16 @@ void UMLViewDialog::applyPage(KPageWidgetItem *item)
     }
     else if (item == m_pageFontItem)
     {
-        uDebug() << "setting font " << m_pChooser->font().toString();
-        m_pScene->setFont(m_pChooser->font(), true);
+#if QT_VERSION >= 0x050000
+        QFont font = m_pChooser->currentFont();
+#else
+        QFont font = m_pChooser->font();
+#endif
+        uDebug() << "setting font " << font.toString();
+        m_pScene->setFont(font, true);
     }
     else if (item == m_pageDisplayItem)
     {
         m_pOptionsPage->apply();
-        if (m_pScene->type() != Uml::DiagramType::Class) {
-            return;
-        }
-        m_pScene->setClassWidgetOptions(m_pOptionsPage);
-        //       sig = m_pTempWidget->getShowOpSigs();
-        //       showSig = !(sig == Uml::st_NoSig || sig == Uml::st_NoSigNoVis);
-        //       options.classState.showOpSig = showSig;
-        //       sig = m_pTempWidget->getShowAttSigs();
-        //       showSig = !(sig == Uml::st_NoSig || sig == Uml::st_NoSigNoVis);
-        //       options.classState.showAttSig = showSig;
-        m_pScene->setOptionState(m_options);
     }
 }
-
-#include "umlviewdialog.moc"
