@@ -26,7 +26,7 @@
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
 #include <kconfig.h>
-#include <klocale.h>
+#include <KLocalizedString>
 #include <ktip.h>
 #include <kwin.h>
 
