@@ -36,7 +36,7 @@
 #include "codegenerator.h"
 
 // kde includes
-#include <klocale.h>
+#include <KLocalizedString>
 
 // qt includes
 #include <QRegExp>
@@ -215,6 +215,7 @@ UMLObject* findUMLObject(const UMLObjectList& inList,
             UMLObjectList objectsInCurrentScope = pkg->containedObjects();
             for (UMLObjectListIt oit(objectsInCurrentScope); oit.hasNext();) {
                 UMLObject *obj = oit.next();
+                uIgnoreZeroPointer(obj);
                 if (caseSensitive) {
                     if (obj->name() != name)
                         continue;
@@ -261,6 +262,7 @@ UMLObject* findUMLObject(const UMLObjectList& inList,
     }
     for (UMLObjectListIt oit(inList); oit.hasNext();) {
         UMLObject *obj = oit.next();
+        uIgnoreZeroPointer(obj);
         if (caseSensitive) {
             if (obj->name() != name)
                 continue;
@@ -1049,6 +1051,29 @@ bool typeIsClassifier(UMLListViewItem::ListViewType type)
     return false;
 }
 
+/**
+ * Return true if the listview type is a settings entry.
+ */
+bool typeIsProperties(UMLListViewItem::ListViewType type)
+{
+    switch (type) {
+    case UMLListViewItem::lvt_Properties:
+    case UMLListViewItem::lvt_Properties_AutoLayout:
+    case UMLListViewItem::lvt_Properties_Class:
+    case UMLListViewItem::lvt_Properties_CodeImport:
+    case UMLListViewItem::lvt_Properties_CodeGeneration:
+    case UMLListViewItem::lvt_Properties_CodeViewer:
+    case UMLListViewItem::lvt_Properties_Font:
+    case UMLListViewItem::lvt_Properties_General:
+    case UMLListViewItem::lvt_Properties_UserInterface:
+        return true;
+        break;
+    default:
+        break;
+    }
+    return false;
+}
+
 /**
  * Check if a listviewitem of type childType is allowed
  * as child of type parentType
@@ -1680,7 +1705,33 @@ Icon_Utils::IconType convert_LVT_IT(UMLListViewItem::ListViewType lvt, UMLObject
         case UMLListViewItem::lvt_EntityRelationship_Diagram:
             icon = Icon_Utils::it_Diagram_EntityRelationship;
             break;
-
+        case UMLListViewItem::lvt_Properties:
+            icon = Icon_Utils::it_Properties;
+            break;
+        case UMLListViewItem::lvt_Properties_AutoLayout:
+            icon = Icon_Utils::it_Properties_AutoLayout;
+            break;
+        case UMLListViewItem::lvt_Properties_Class:
+            icon = Icon_Utils::it_Properties_Class;
+            break;
+        case UMLListViewItem::lvt_Properties_CodeImport:
+            icon = Icon_Utils::it_Properties_CodeImport;
+            break;
+        case UMLListViewItem::lvt_Properties_CodeGeneration:
+            icon = Icon_Utils::it_Properties_CodeGeneration;
+            break;
+        case UMLListViewItem::lvt_Properties_CodeViewer:
+            icon = Icon_Utils::it_Properties_CodeViewer;
+            break;
+        case UMLListViewItem::lvt_Properties_Font:
+            icon = Icon_Utils::it_Properties_Font;
+            break;
+        case UMLListViewItem::lvt_Properties_General:
+            icon = Icon_Utils::it_Properties_General;
+            break;
+        case UMLListViewItem::lvt_Properties_UserInterface:
+            icon = Icon_Utils::it_Properties_UserInterface;
+            break;
         default:
             break;
     }
@@ -1731,6 +1782,49 @@ Uml::DiagramType::Enum convert_LVT_DT(UMLListViewItem::ListViewType lvt)
     return dt;
 }
 
+/**
+ * Converts a list view type enum to the equivalent settings dialog type.
+ *
+ * @param lvt   The ListViewType to convert.
+ * @return  The converted settings dialog type
+ */
+MultiPageDialogBase::PageType convert_LVT_PT(UMLListViewItem::ListViewType type)
+{
+    MultiPageDialogBase::PageType pt = MultiPageDialogBase::GeneralPage;
+    switch (type) {
+    case UMLListViewItem::lvt_Properties:
+        pt = MultiPageDialogBase::GeneralPage;
+        break;
+    case UMLListViewItem::lvt_Properties_AutoLayout:
+        pt = MultiPageDialogBase::AutoLayoutPage;
+        break;
+    case UMLListViewItem::lvt_Properties_Class:
+        pt = MultiPageDialogBase::ClassPage;
+        break;
+    case UMLListViewItem::lvt_Properties_CodeImport:
+        pt = MultiPageDialogBase::CodeImportPage;
+        break;
+    case UMLListViewItem::lvt_Properties_CodeGeneration:
+        pt = MultiPageDialogBase::CodeGenerationPage;
+        break;
+    case UMLListViewItem::lvt_Properties_CodeViewer:
+        pt = MultiPageDialogBase::CodeViewerPage;
+        break;
+    case UMLListViewItem::lvt_Properties_Font:
+        pt = MultiPageDialogBase::FontPage;
+        break;
+    case UMLListViewItem::lvt_Properties_General:
+        pt = MultiPageDialogBase::GeneralPage;
+        break;
+    case UMLListViewItem::lvt_Properties_UserInterface:
+        pt = MultiPageDialogBase::UserInterfacePage;
+        break;
+    default:
+        break;
+    }
+    return pt;
+}
+
 /**
  * Return the Model_Type which corresponds to the given ObjectType.
  */
