@@ -12,17 +12,30 @@
 #define UML_H
 
 #include "basictypes.h"
+#include "multipagedialogbase.h"
 
+// kde includes
 #include <kxmlguiwindow.h>
+#if QT_VERSION < 0x050000
 #include <kurl.h>
+#endif
 #include <ksharedconfig.h>
 
+// qt includes
+#include <QPointer>
+#if QT_VERSION >= 0x050000
+#include <QUrl>
+#endif
+
 // forward declaration of the UML classes
+class BirdView;
+class BirdViewDockWidget;
 class CodeDocument;
 class CodeGenerator;
 class CodeGenerationPolicy;
 class CodeGenPolicyExt;
 class DocWindow;
+class UMLAppPrivate;
 class UMLClassifier;
 class UMLDoc;
 class UMLListView;
@@ -41,7 +54,9 @@ class KRecentFilesAction;
 class KToggleAction;
 class KTabWidget;
 class KMenu;
+#if QT_VERSION < 0x050000
 class KUndoStack;
+#endif
 class KAction;
 
 // Qt forward declarations
@@ -52,13 +67,16 @@ class QVBoxLayout;
 class QKeyEvent;
 class QMenu;
 class QMimeData;
+class QPrinter;
 class QUndoCommand;
 class QUndoView;
+#if QT_VERSION >= 0x050000
+class QUndoStack;
+#endif
 class QPushButton;
 class QLabel;
 class QListWidget;
 class QSlider;
-class UMLAppPrivate;
 
 /**
  * The base class for UML application windows. It sets up the main
@@ -87,7 +105,11 @@ public:
 
     static UMLApp* app();
 
+#if QT_VERSION >= 0x050000
+    void openDocumentFile(const QUrl& url=QUrl());
+#else
     void openDocumentFile(const KUrl& url=KUrl());
+#endif
 
     void newDocument();
 
@@ -141,7 +163,11 @@ public:
 
     bool editCutCopy(bool bFromView);
 
+#if QT_VERSION >= 0x050000
+    QTabWidget *tabWidget();
+#else
     KTabWidget *tabWidget();
+#endif
 
     QString statusBarMsg();
 
@@ -199,7 +225,12 @@ public slots:
 
     void slotFileNew();
     void slotFileOpen();
+
+#if QT_VERSION >= 0x050000
+    void slotFileOpenRecent(const QUrl& url);
+#else
     void slotFileOpenRecent(const KUrl& url);
+#endif
     void slotFileSave();
     bool slotFileSaveAs();
     void slotFileClose();
@@ -236,7 +267,7 @@ public slots:
     void slotAlignHorizontalDistribute();
     void slotClipDataChanged();
     void slotCopyChanged();
-    void slotPrefs();
+    void slotPrefs(MultiPageDialogBase::PageType page = MultiPageDialogBase::GeneralPage);
     void slotApplyPrefs();
     void slotImportClass();
     void slotImportProject();
@@ -246,11 +277,12 @@ public slots:
     void slotShowDocumentationView(bool state);
     void slotShowCmdHistoryView(bool state);
     void slotShowLogView(bool state);
+    void slotShowBirdView(bool state);
     void slotCurrentViewClearDiagram();
     void slotCurrentViewToggleSnapToGrid();
     void slotCurrentViewToggleShowGrid();
     void slotCurrentViewExportImage();
-    void slotAllViewsExportImage();
+    void slotViewsExportImages();
     void slotCurrentProperties();
     void slotClassWizard();
     void slotAddDefaultDatatypes();
@@ -260,7 +292,11 @@ public slots:
     void slotSelectAll();
     void slotDeleteSelected();
     void slotDeleteDiagram();
+#if QT_VERSION >= 0x050000
+    void slotCloseDiagram(int index);
+#else
     void slotCloseDiagram(QWidget* tab);
+#endif
     void slotGenerateAllCode();
 
     void slotSetZoom(QAction* action);
@@ -270,12 +306,18 @@ public slots:
     void slotZoomOut();
     void slotZoomIn();
 
+    void slotBirdViewChanged(const QPoint& delta);
+
     void setupZoomMenu();
 
     void slotEditUndo();
     void slotEditRedo();
 
+#if QT_VERSION >= 0x050000
+    void slotTabChanged(int index);
+#else
     void slotTabChanged(QWidget* tab);
+#endif
     void slotChangeTabLeft();
     void slotChangeTabRight();
     void slotMoveTabLeft();
@@ -304,6 +346,9 @@ private slots:
     void setLang_tcl();
     void setLang_vala();
     void setLang_xmlschema();
+#if QT_VERSION >= 0x050000
+    void slotDiagramPopupMenu(const QPoint& point);
+#endif
 
 private:
     static UMLApp* s_instance;  ///< The last created instance of this class.
@@ -312,7 +357,7 @@ private:
     QMenu* findMenu(const QString &name);
 
     QAction* createZoomAction(int zoom, int currentZoom);
-    void setZoom(int zoom);
+    void setZoom(int zoom, bool withView = true);
 
     void resetStatusMsg();
 
@@ -327,6 +372,8 @@ private:
 
     void createDiagram(Uml::DiagramType::Enum type);
 
+    void createBirdView(UMLView* view);
+
     QMenu* m_langSelect;  ///< For selecting the active language.
     QMenu* m_zoomSelect;  ///< Popup menu for zoom selection.
 
@@ -362,8 +409,11 @@ private:
     QDockWidget* m_cmdHistoryDock;     ///< Contains the undo/redo viewer widget.
     QDockWidget* m_propertyDock;       ///< Contains the property browser widget.
     QDockWidget* m_logDock;            ///< Contains the log window widget.
+    BirdViewDockWidget* m_birdViewDock;///< Contains the bird's eye view
 
-    DocWindow*   m_docWindow;         ///< Documentation window.
+    DocWindow*   m_docWindow;          ///< Documentation window.
+    QListWidget* m_logWindow;          ///< Logging window.
+    BirdView*    m_birdView;           ///< Bird View window
     QUndoView*   m_pQUndoView;         ///< Undo / Redo Viewer
     RefactoringAssistant* m_refactoringAssist;  ///< Refactoring assistant.
 
@@ -382,6 +432,7 @@ private:
     QAction* viewShowDoc;
     QAction* viewShowLog;
     QAction* viewShowCmdHistory;
+    QAction* viewShowBirdView;
 
     KActionMenu* newDiagram;
     QAction* viewClearDiagram;
@@ -394,9 +445,13 @@ private:
     QAction* zoom100Action;
 
     QAction* m_langAct[Uml::ProgrammingLanguage::Reserved];
+#if QT_VERSION >= 0x050000
+    QAction* deleteSelectedWidget;
+    QAction* deleteDiagram;
+#else
     KAction* deleteSelectedWidget;
     KAction* deleteDiagram;
-
+#endif
     QToolButton* m_newSessionButton;
     KMenu* m_diagramMenu;
     WorkToolBar* m_toolsbar;
@@ -415,7 +470,11 @@ private:
      * Shows, and is parent of, all the UMLViews (diagrams)
      * if tabbed diagrams are enabled.
      */
+#if QT_VERSION >= 0x050000
+    QTabWidget* m_tabWidget;
+#else
     KTabWidget* m_tabWidget;
+#endif
 
     /**
      * Layout supports the dynamic management of the diagram representation (tabbed/stacked)
@@ -445,17 +504,22 @@ private:
      */
     XhtmlGenerator* m_xhtmlGenerator;
 
+#if QT_VERSION >= 0x050000
+    QUndoStack* m_pUndoStack;  ///< UndoStack used to store actions, to provide Undo/Redo feature.
+#else
     KUndoStack* m_pUndoStack;  ///< UndoStack used to store actions, to provide Undo/Redo feature.
+#endif
     bool m_undoEnabled; ///< Undo enabled flag
 
     bool m_hasBegunMacro;  ///< Macro creation flag.
 
-    DiagramPrintPage *m_printSettings; ///< printer diagram settings
+    QPointer<DiagramPrintPage> m_printSettings; ///< printer diagram settings
     QPrinter *m_printer;               ///< print instance
 
 signals:
     void sigCutSuccessful();
 
+    friend class UMLView;
 };
 
 #endif // UML_H
