@@ -31,8 +31,8 @@
 #include "cmds.h"
 
 // kde includes
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <KLocalizedString>
+#include <KMessageBox>
 
 // qt includes
 #include <QDrag>
@@ -402,9 +402,10 @@ void UMLListViewItem::updateFolder()
     Icon_Utils::IconType icon = Model_Utils::convert_LVT_IT(m_type, m_object);
 
     if (icon) {
-        if (Model_Utils::typeIsFolder(m_type))
+        if (Model_Utils::typeIsFolder(m_type)) {
             icon = (Icon_Utils::IconType)((int)icon + (int)isExpanded());
-        setIcon(icon);
+        }
+//FIXME KF5        setIcon(icon);
     }
 }
 
@@ -449,7 +450,9 @@ QString UMLListViewItem::getSavedText() const
 void UMLListViewItem::setIcon(Icon_Utils::IconType iconType)
 {
     QPixmap p = Icon_Utils::SmallIcon(iconType);
-    QTreeWidgetItem::setIcon(0, QIcon(p));
+    if (!p.isNull()) {
+        QTreeWidgetItem::setIcon(0, QIcon(p));
+    }
 }
 
 /**
@@ -1029,6 +1032,8 @@ QString UMLListViewItem::toString(ListViewType type)
             return QLatin1String("lvt_CheckConstraint");
         case lvt_Category:
             return QLatin1String("lvt_Category");
+        case lvt_Properties:
+            return QLatin1String("lvt_Properties");
         case lvt_Unknown:
             return QLatin1String("lvt_Unknown");
         default:
