@@ -41,7 +41,7 @@ void TEST_cppwriter::test_language()
 {
     CppWriter* cpp = new CppWriter();
     Uml::ProgrammingLanguage::Enum lang = cpp->language();
-    QCOMPARE(lang, Uml::ProgrammingLanguage::Cpp);
+    QVERIFY(lang == Uml::ProgrammingLanguage::Cpp);
 }
 
 void TEST_cppwriter::test_writeClass()
